@@ -1,16 +1,16 @@
 /* Define the comparison_fn_t type from GNU Libc.
  *
- * Copyright (C) 2005 Oskar Liljeblad
+ * Copyright (C) 2005, 2007, 2008 Oskar Liljeblad
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ * the Free Software Foundation; either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation,
@@ -32,4 +32,6 @@
 typedef int (*comparison_fn_t)(const void *, const void *);
 #endif
 
+typedef int (*complex_comparison_fn_t)(const void *, const void *, void *);
+
 #endif
